import { 
  select, 
  csv, 
  scaleLinear,  
  max, 
  axisLeft,
  axisBottom,
  format,
  scaleTime,
  extent,
  line
} from 'd3';

const svg = select('svg');
const height = +svg.attr('height');
const width = parseFloat(svg.attr('width')); 

const render = (data) => {
  const title = "A Week in San Francisco Line Chart"
  const xAxisLabel = "Time";
  const xValue = (d) => { 
      return d.timestamp 
    };
  const yAxisLabel = "Temperature"
  const yValue = (d) =>{
  	return d.temperature;
  };
  
  const margin = { top: 60, right: 40, bottom: 100, left: 105 };
	const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 6;
 
  const xScale = scaleTime()
  	.domain(extent(data,xValue))
  	.range([0, innerWidth])
  	.nice(); //.nice makes grid lines end on a tick. 
  
  
  const yScale = scaleLinear()
  	.domain(extent(data,yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  //set svg margins 
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  

  const xAxis = axisBottom(xScale)
  								.tickSize(-innerHeight)
  								.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  								.tickSize(-innerWidth)
  								.tickPadding(10);  
    
	
  const yAxisG = g.append('g')
  	.call(yAxis);
  
  //remove tick
  yAxisG
  	.selectAll('.domain')
  	.remove();
  
    yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -70)
  	.attr('x', - innerHeight / 2)
  	.attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
          
          
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
    
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 95)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  //Line 
  const lineGenerator = line()
  		.x(d => xScale(xValue(d)))
  		.y(d => yScale(yValue(d)));
  //append line path
  g.append('path')
  	.attr('class','line-path')
		.attr('d', lineGenerator(data)), 
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
  g.append('text')
  	.attr('class', 'title')
  	.text(title)
  	.attr('y', -10);
  
}

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data =>{
  	data.forEach(d => {
			d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp)
    })
    render(data);
  });